@@ -23,14 +23,15 @@
 
 #include "crypto_pwhash_scryptsalsa208sha256.h"
 #include "crypto_scrypt.h"
+#include "private/common.h"
 #include "runtime.h"
 #include "utils.h"
 
-static const char * const itoa64 =
+static const char *const itoa64 =
     "./0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
 
 static uint8_t *
-encode64_uint32(uint8_t * dst, size_t dstlen, uint32_t src, uint32_t srcbits)
+encode64_uint32(uint8_t *dst, size_t dstlen, uint32_t src, uint32_t srcbits)
 {
     uint32_t bit;
 
@@ -42,22 +43,23 @@ encode64_uint32(uint8_t * dst, size_t dstlen, uint32_t src, uint32_t srcbits)
         dstlen--;
         src >>= 6;
     }
-
     return dst;
 }
 
 static uint8_t *
-encode64(uint8_t * dst, size_t dstlen, const uint8_t * src, size_t srclen)
+encode64(uint8_t *dst, size_t dstlen, const uint8_t *src, size_t srclen)
 {
     size_t i;
 
-    for (i = 0; i < srclen; ) {
-        uint8_t * dnext;
+    for (i = 0; i < srclen;) {
+        uint8_t *dnext;
         uint32_t value = 0, bits = 0;
+
         do {
-            value |= (uint32_t)src[i++] << bits;
+            value |= (uint32_t) src[i++] << bits;
             bits += 8;
         } while (bits < 24 && i < srclen);
+
         dnext = encode64_uint32(dst, dstlen, value, bits);
         if (!dnext) {
             return NULL; /* LCOV_EXCL_LINE */
@@ -65,25 +67,25 @@ encode64(uint8_t * dst, size_t dstlen, const uint8_t * src, size_t srclen)
         dstlen -= dnext - dst;
         dst = dnext;
     }
-
     return dst;
 }
 
 static int
-decode64_one(uint32_t * dst, uint8_t src)
+decode64_one(uint32_t *dst, uint8_t src)
 {
     const char *ptr = strchr(itoa64, src);
 
     if (ptr) {
-        *dst = (uint32_t) (ptr - itoa64);
+        *dst = (uint32_t)(ptr - itoa64);
         return 0;
     }
     *dst = 0;
+
     return -1;
 }
 
 static const uint8_t *
-decode64_uint32(uint32_t * dst, uint32_t dstbits, const uint8_t * src)
+decode64_uint32(uint32_t *dst, uint32_t dstbits, const uint8_t *src)
 {
     uint32_t bit;
     uint32_t value;
@@ -98,14 +100,14 @@ decode64_uint32(uint32_t * dst, uint32_t dstbits, const uint8_t * src)
         src++;
         value |= one << bit;
     }
-
     *dst = value;
+
     return src;
 }
 
 uint8_t *
-escrypt_r(escrypt_local_t * local, const uint8_t * passwd, size_t passwdlen,
-          const uint8_t * setting, uint8_t * buf, size_t buflen)
+escrypt_r(escrypt_local_t *local, const uint8_t *passwd, size_t passwdlen,
+          const uint8_t *setting, uint8_t *buf, size_t buflen)
 {
     uint8_t        hash[crypto_pwhash_scryptsalsa208sha256_STRHASHBYTES];
     escrypt_kdf_t  escrypt_kdf;
@@ -129,7 +131,7 @@ escrypt_r(escrypt_local_t * local, const uint8_t * passwd, size_t passwdlen,
         return NULL;
     }
     src++;
-    N = (uint64_t)1 << N_log2;
+    N = (uint64_t) 1 << N_log2;
 
     src = decode64_uint32(&r, 30, src);
     if (!src) {
@@ -142,29 +144,27 @@ escrypt_r(escrypt_local_t * local, const uint8_t * passwd, size_t passwdlen,
     prefixlen = src - setting;
 
     salt = src;
-    src = (uint8_t *) strrchr((char *)salt, '$');
+    src  = (uint8_t *) strrchr((char *) salt, '$');
     if (src) {
         saltlen = src - salt;
     } else {
-        saltlen = strlen((char *)salt);
+        saltlen = strlen((char *) salt);
     }
     need = prefixlen + saltlen + 1 +
-        crypto_pwhash_scryptsalsa208sha256_STRHASHBYTES_ENCODED + 1;
+           crypto_pwhash_scryptsalsa208sha256_STRHASHBYTES_ENCODED + 1;
     if (need > buflen || need < saltlen) {
         return NULL;
     }
-#if defined(HAVE_EMMINTRIN_H) || \
-    (defined(_MSC_VER) && (defined(_M_X64) || defined(_M_AMD64) || defined(_M_IX86)))
+#ifdef HAVE_EMMINTRIN_H
     escrypt_kdf =
         sodium_runtime_has_sse2() ? escrypt_kdf_sse : escrypt_kdf_nosse;
 #else
     escrypt_kdf = escrypt_kdf_nosse;
 #endif
-    if (escrypt_kdf(local, passwd, passwdlen, salt, saltlen,
-                    N, r, p, hash, sizeof(hash))) {
+    if (escrypt_kdf(local, passwd, passwdlen, salt, saltlen, N, r, p, hash,
+                    sizeof(hash))) {
         return NULL;
     }
-
     dst = buf;
     memcpy(dst, setting, prefixlen + saltlen);
     dst += prefixlen + saltlen;
@@ -181,24 +181,23 @@ escrypt_r(escrypt_local_t * local, const uint8_t * passwd, size_t passwdlen,
 }
 
 uint8_t *
-escrypt_gensalt_r(uint32_t N_log2, uint32_t r, uint32_t p,
-                  const uint8_t * src, size_t srclen,
-                  uint8_t * buf, size_t buflen)
+escrypt_gensalt_r(uint32_t N_log2, uint32_t r, uint32_t p, const uint8_t *src,
+                  size_t srclen, uint8_t *buf, size_t buflen)
 {
     uint8_t *dst;
     size_t   prefixlen =
         (sizeof "$7$" - 1U) + (1U /* N_log2 */) + (5U /* r */) + (5U /* p */);
-    size_t   saltlen = BYTES2CHARS(srclen);
-    size_t   need;
+    size_t saltlen = BYTES2CHARS(srclen);
+    size_t need;
 
     need = prefixlen + saltlen + 1;
     if (need > buflen || need < saltlen || saltlen < srclen) {
         return NULL; /* LCOV_EXCL_LINE */
     }
-    if (N_log2 > 63 || ((uint64_t)r * (uint64_t)p >= (1U << 30))) {
+    if (N_log2 > 63 || ((uint64_t) r * (uint64_t) p >= (1U << 30))) {
         return NULL;
     }
-    dst = buf;
+    dst    = buf;
     *dst++ = '$';
     *dst++ = '7';
     *dst++ = '$';
@@ -223,10 +222,10 @@ escrypt_gensalt_r(uint32_t N_log2, uint32_t r, uint32_t p,
 }
 
 int
-crypto_pwhash_scryptsalsa208sha256_ll(const uint8_t * passwd, size_t passwdlen,
-                                      const uint8_t * salt, size_t saltlen,
+crypto_pwhash_scryptsalsa208sha256_ll(const uint8_t *passwd, size_t passwdlen,
+                                      const uint8_t *salt, size_t saltlen,
                                       uint64_t N, uint32_t r, uint32_t p,
-                                      uint8_t * buf, size_t buflen)
+                                      uint8_t *buf, size_t buflen)
 {
     escrypt_kdf_t   escrypt_kdf;
     escrypt_local_t local;
@@ -235,16 +234,14 @@ crypto_pwhash_scryptsalsa208sha256_ll(const uint8_t * passwd, size_t passwdlen,
     if (escrypt_init_local(&local)) {
         return -1; /* LCOV_EXCL_LINE */
     }
-#if defined(HAVE_EMMINTRIN_H) || \
-    (defined(_MSC_VER) && (defined(_M_X64) || defined(_M_AMD64) || defined(_M_IX86)))
+#if defined(HAVE_EMMINTRIN_H)
     escrypt_kdf =
         sodium_runtime_has_sse2() ? escrypt_kdf_sse : escrypt_kdf_nosse;
 #else
     escrypt_kdf = escrypt_kdf_nosse;
 #endif
-    retval = escrypt_kdf(&local,
-                         passwd, passwdlen, salt, saltlen,
-                         N, r, p, buf, buflen);
+    retval = escrypt_kdf(&local, passwd, passwdlen, salt, saltlen, N, r, p, buf,
+                         buflen);
     if (escrypt_free_local(&local)) {
         return -1; /* LCOV_EXCL_LINE */
     }
